==> AsposeCellsCloud-CellsApi-25.1.tar.gz: AsposeCellsCloud-CellsApi-25.1/lib/AsposeCellsCloud/Object/FilterColumn.pm <==
=begin comment

Copyright (c) 2025 Aspose.Cells Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

=end comment

=cut

package AsposeCellsCloud::Object::FilterColumn;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;
use AsposeCellsCloud::Object::ColorFilter;
use AsposeCellsCloud::Object::CustomFilter;
use AsposeCellsCloud::Object::DynamicFilter;
use AsposeCellsCloud::Object::IconFilter;
use AsposeCellsCloud::Object::MultipleFilters;
use AsposeCellsCloud::Object::Top10Filter; 


use base ("Class::Accessor", "Class::Data::Inheritable");



__PACKAGE__->mk_classdata('attribute_map' => {});
__PACKAGE__->mk_classdata('swagger_types' => {});
__PACKAGE__->mk_classdata('method_documentation' => {}); 
__PACKAGE__->mk_classdata('class_documentation' => {});

# new object
sub new { 
    my ($class, %args) = @_; 

	my $self = bless {}, $class;

	foreach my $attribute (keys %{$class->attribute_map}) {
		my $args_key = $class->attribute_map->{$attribute};
		$self->$attribute( $args{ $args_key } );
	}

	return $self;
}  

# return perl hash
sub to_hash {
    return decode_json(JSON->new->convert_blessed->encode( shift ));
}

# used by JSON for serialization
sub TO_JSON { 
    my $self = shift;
    my $_data = {};
    foreach my $_key (keys %{$self->attribute_map}) {
        if (defined $self->{$_key}) {
            $_data->{$self->attribute_map->{$_key}} = $self->{$_key};
        }
    }
    return $_data;
}

# from Perl hashref
sub from_hash {
    my ($self, $hash) = @_;

    # loop through attributes and use swagger_types to deserialize the data
    while ( my ($_key, $_type) = each %{$self->swagger_types} ) {
    	my $_json_attribute = $self->attribute_map->{$_key}; 
        if ($_type =~ /^array\[/i) { # array
            my $_subclass = substr($_type, 6, -1);
            my @_array = ();
            foreach my $_element (@{$hash->{$_json_attribute}}) {
                push @_array, $self->_deserialize($_subclass, $_element);
            }
            $self->{$_key} = \@_array;
        } elsif (exists $hash->{$_json_attribute}) { #hash(model), primitive, datetime
            $self->{$_key} = $self->_deserialize($_type, $hash->{$_json_attribute});
        } else {
        	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
        }
    }

    return $self;
}

# deserialize non-array data
sub _deserialize {
    my ($self, $type, $data) = @_;
    $log->debugf("deserializing %s with %s",Dumper($data), $type);

    if ($type eq 'DateTime') {
        return DateTime->from_epoch(epoch => str2time($data));
    } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
        return $data;
    } else { # hash(model)
        my $_instance = eval "AsposeCellsCloud::Object::$type->new()";
        return $_instance->from_hash($data);
    }
}


__PACKAGE__->class_documentation({description => '           Represents a filter for a single column. The Filter object is a member of the Filters collection           ',
                                  class => 'FilterColumn',
                                  required => [], # TODO
}                                 );


__PACKAGE__->method_documentation({
     'field_index' => {
     	datatype => 'int',
     	base_name => 'FieldIndex',
     	description => 'Gets and sets the column offset in the range. ',
     	format => '',
     	read_only => '',
     		},
     'filter_type' => {
     	datatype => 'string',
     	base_name => 'FilterType',
     	description => 'Gets and sets the type fo filtering data. ',
     	format => '',
     	read_only => '',
     		},
     'multiple_filters' => {
     	datatype => 'MultipleFilters',
     	base_name => 'MultipleFilters',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'color_filter' => {
     	datatype => 'ColorFilter',
     	base_name => 'ColorFilter',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'custom_filters' => {
     	datatype => 'ARRAY[CustomFilter]',
     	base_name => 'CustomFilters',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'dynamic_filter' => {
     	datatype => 'DynamicFilter',
     	base_name => 'DynamicFilter',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'icon_filter' => {
     	datatype => 'IconFilter',
     	base_name => 'IconFilter',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'top10_filter' => {
     	datatype => 'Top10Filter',
     	base_name => 'Top10Filter',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'visibledropdown' => {
     	datatype => 'string',
     	base_name => 'Visibledropdown',
     	description => 'Indicates whether the AutoFilter button for this column is visible. ',
     	format => '',
     	read_only => '',
     		},    
});

__PACKAGE__->swagger_types( {
    'field_index' => 'int',
    'filter_type' => 'string',
    'multiple_filters' => 'MultipleFilters',
    'color_filter' => 'ColorFilter',
    'custom_filters' => 'ARRAY[CustomFilter]',
    'dynamic_filter' => 'DynamicFilter',
    'icon_filter' => 'IconFilter',
    'top10_filter' => 'Top10Filter',
    'visibledropdown' => 'string' 
} );

__PACKAGE__->attribute_map( {
    'field_index' => 'FieldIndex',
    'filter_type' => 'FilterType',
    'multiple_filters' => 'MultipleFilters',
    'color_filter' => 'ColorFilter',
    'custom_filters' => 'CustomFilters',
    'dynamic_filter' => 'DynamicFilter',
    'icon_filter' => 'IconFilter',
    'top10_filter' => 'Top10Filter',
    'visibledropdown' => 'Visibledropdown' 
} );

__PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});


1;

==> AsposeCellsCloud-CellsApi-25.3.tar.gz: AsposeCellsCloud-CellsApi-25.3/lib/AsposeCellsCloud/Object/FilterColumn.pm <==
=begin comment

Copyright (c) 2025 Aspose.Cells Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

=end comment

=cut

package AsposeCellsCloud::Object::FilterColumn;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;
use AsposeCellsCloud::Object::ColorFilter;
use AsposeCellsCloud::Object::CustomFilter;
use AsposeCellsCloud::Object::DynamicFilter;
use AsposeCellsCloud::Object::IconFilter;
use AsposeCellsCloud::Object::MultipleFilters;
use AsposeCellsCloud::Object::Top10Filter; 


use base ("Class::Accessor", "Class::Data::Inheritable");



__PACKAGE__->mk_classdata('attribute_map' => {});
__PACKAGE__->mk_classdata('swagger_types' => {});
__PACKAGE__->mk_classdata('method_documentation' => {}); 
__PACKAGE__->mk_classdata('class_documentation' => {});

# new object
sub new { 
    my ($class, %args) = @_; 

	my $self = bless {}, $class;

	foreach my $attribute (keys %{$class->attribute_map}) {
		my $args_key = $class->attribute_map->{$attribute};
		$self->$attribute( $args{ $args_key } );
	}

	return $self;
}  

# return perl hash
sub to_hash {
    return decode_json(JSON->new->convert_blessed->encode( shift ));
}

# used by JSON for serialization
sub TO_JSON { 
    my $self = shift;
    my $_data = {};
    foreach my $_key (keys %{$self->attribute_map}) {
        if (defined $self->{$_key}) {
            $_data->{$self->attribute_map->{$_key}} = $self->{$_key};
        }
    }
    return $_data;
}

# from Perl hashref
sub from_hash {
    my ($self, $hash) = @_;

    # loop through attributes and use swagger_types to deserialize the data
    while ( my ($_key, $_type) = each %{$self->swagger_types} ) {
    	my $_json_attribute = $self->attribute_map->{$_key}; 
        if ($_type =~ /^array\[/i) { # array
            my $_subclass = substr($_type, 6, -1);
            my @_array = ();
            foreach my $_element (@{$hash->{$_json_attribute}}) {
                push @_array, $self->_deserialize($_subclass, $_element);
            }
            $self->{$_key} = \@_array;
        } elsif (exists $hash->{$_json_attribute}) { #hash(model), primitive, datetime
            $self->{$_key} = $self->_deserialize($_type, $hash->{$_json_attribute});
        } else {
        	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
        }
    }

    return $self;
}

# deserialize non-array data
sub _deserialize {
    my ($self, $type, $data) = @_;
    $log->debugf("deserializing %s with %s",Dumper($data), $type);

    if ($type eq 'DateTime') {
        return DateTime->from_epoch(epoch => str2time($data));
    } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
        return $data;
    } else { # hash(model)
        my $_instance = eval "AsposeCellsCloud::Object::$type->new()";
        return $_instance->from_hash($data);
    }
}


__PACKAGE__->class_documentation({description => '           Represents a filter for a single column. The Filter object is a member of the Filters collection           ',
                                  class => 'FilterColumn',
                                  required => [], # TODO
}                                 );


__PACKAGE__->method_documentation({
     'field_index' => {
     	datatype => 'int',
     	base_name => 'FieldIndex',
     	description => 'Gets and sets the column offset in the range. ',
     	format => '',
     	read_only => '',
     		},
     'filter_type' => {
     	datatype => 'string',
     	base_name => 'FilterType',
     	description => 'Gets and sets the type fo filtering data. ',
     	format => '',
     	read_only => '',
     		},
     'multiple_filters' => {
     	datatype => 'MultipleFilters',
     	base_name => 'MultipleFilters',
     	description => 'This class contains a property named "MultipleFilters" of type "MultipleFilters" that can be both read and written.',
     	format => '',
     	read_only => '',
     		},
     'color_filter' => {
     	datatype => 'ColorFilter',
     	base_name => 'ColorFilter',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'custom_filters' => {
     	datatype => 'ARRAY[CustomFilter]',
     	base_name => 'CustomFilters',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'dynamic_filter' => {
     	datatype => 'DynamicFilter',
     	base_name => 'DynamicFilter',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'icon_filter' => {
     	datatype => 'IconFilter',
     	base_name => 'IconFilter',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'top10_filter' => {
     	datatype => 'Top10Filter',
     	base_name => 'Top10Filter',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'visibledropdown' => {
     	datatype => 'string',
     	base_name => 'Visibledropdown',
     	description => 'Indicates whether the AutoFilter button for this column is visible. ',
     	format => '',
     	read_only => '',
     		},    
});

__PACKAGE__->swagger_types( {
    'field_index' => 'int',
    'filter_type' => 'string',
    'multiple_filters' => 'MultipleFilters',
    'color_filter' => 'ColorFilter',
    'custom_filters' => 'ARRAY[CustomFilter]',
    'dynamic_filter' => 'DynamicFilter',
    'icon_filter' => 'IconFilter',
    'top10_filter' => 'Top10Filter',
    'visibledropdown' => 'string' 
} );

__PACKAGE__->attribute_map( {
    'field_index' => 'FieldIndex',
    'filter_type' => 'FilterType',
    'multiple_filters' => 'MultipleFilters',
    'color_filter' => 'ColorFilter',
    'custom_filters' => 'CustomFilters',
    'dynamic_filter' => 'DynamicFilter',
    'icon_filter' => 'IconFilter',
    'top10_filter' => 'Top10Filter',
    'visibledropdown' => 'Visibledropdown' 
} );

__PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});


1;
